@@ -1,7 +1,7 @@
 """Upload files to online mirroring services."""
-from mirror_ace import MirrorAceConnection  # noqa
+from mirror_up.mirror_ace import MirrorAceConnection  # noqa
 
 __author__ = """Mycsina"""
 __email__ = "mycsina@protonmail.com"
-__version__ = "0.1.4"
+__version__ = "0.1.6"
 APP_NAME = "mirror-up"
